using System.ComponentModel;
using System.Collections;
using iAnywhere.Data.UltraLite;

namespace iAnywhere.Data.UltraLite.DataGridDataSource
{

    /// <summary><para> Encapsulates an Ultralite <see cref="iAnywhere.Data.UltraLite.ULTable"/>
    /// or <see cref="iAnywhere.Data.UltraLite.ULResultSet"/> into a datasource that can be 
    /// used by a .NET <see cref="System.Windows.Forms.DataGrid"/>.</para></summary>
    /// <remarks><para>The constructor takes a <see cref="iAnywhere.UltraLite.Table"/>
    /// object and creates datasource that can be given to a .NET datagrid using the
    /// <see cref.System.Windows.Forms.DataGrid.DataSource"/> property.</para>
    /// <para>This class implements the <see cref="System.ComponentModel.IListSource"/> interface.
    /// </para></remarks>
    public class DataGridDataSource : IListSource
    {
        CustomTable _table;

        /// <summary><para> The constructor takes a <see cref="iAnywhere.Data.UltraLite.ULTable"/>
        /// object and creates datasource that can be given to a .NET datagrid using the
        /// <see cref.System.Windows.Forms.DataGrid.DataSource"/> property.</para></summary>
        public DataGridDataSource(ULDataReader table)
        {
            _table = new CustomTable(table);
        }

        /// <summary><para>Indicates whether the collection is a collection of
        /// <see cref=System.Collections.IList"/> objects.</para></summary>
        /// <remarks><para>This method always returns true, since the table consists of only one
        /// <see cref=System.Collections.IList"/> objects.</para></remarks>
        public bool ContainsListCollection
        {
            get
            {
                return false;
            }
        }

        /// <summary><para>Gets the table that encapsulates the UltraLite table.</para></summary>
        public IList GetList()
        {
            return _table;
        }
    }
}   
