using System;
using System.Collections;
using System.ComponentModel;
using iAnywhere.Data.UltraLite;

namespace iAnywhere.Data.UltraLite.DataGridDataSource
{

    /// <summary><para>This classes contains type converstion
    /// related methods.</para></summary>
    internal class ULDNETBridgeHelper
    {
        // Returns the .NET equivalent of the SQLType type
        internal static System.Type GetNETType(ULDbType sqlType)
        {
            switch (sqlType)
            {
                case ULDbType.Binary:
                    return typeof(System.Byte[]);
                case ULDbType.Bit:
                    return typeof(bool);
                case ULDbType.Char:
                    return typeof(System.String);
                case ULDbType.Date:
                    return typeof(System.DateTime);
                case ULDbType.Double:
                    return typeof(System.Double);
                case ULDbType.LongBinary:
                    return typeof(System.Byte[]);
                case ULDbType.LongVarchar:
                    return typeof(System.String);
                case ULDbType.Numeric:
                    return typeof(System.String);
                case ULDbType.Real:
                    return typeof(System.Single);
                case ULDbType.BigInt:
                    return typeof(System.Int64);
                case ULDbType.Integer:
                    return typeof(System.Int32);
                case ULDbType.SmallInt:
                    return typeof(System.Int16);
                case ULDbType.Time:
                    return typeof(System.TimeSpan);
                case ULDbType.TimeStamp:
                    return typeof(System.DateTime);
                case ULDbType.TinyInt:
                    return typeof(System.Byte);
                case ULDbType.UnsignedBigInt:
                    return typeof(System.UInt64);
                case ULDbType.UnsignedInt:
                    return typeof(System.UInt32);
                case ULDbType.UnsignedSmallInt:
                    return typeof(System.UInt16);
                case ULDbType.VarChar:
                    return typeof(System.String);
                default:
                    return null;
            }
        }

        // populates the blank row with the current row of the table
        internal static bool GetCurrentRowData(ULDataReader table, ULCursorSchema schema, CustomTableRow row)
        {

            short numberOfColumns = schema.ColumnCount;
            for (short j = 0; j < numberOfColumns; j++)
            {
                if (!getRowColData(table, schema, row, j)) return false;
            }
            return true;
        }

        // populates the blank row's specified column using the table's current row
        private static bool getRowColData(ULDataReader table, ULCursorSchema schema, CustomTableRow row, short colIndex)
        {
            //call appropriate method for retrieving column data in
            //row (depends on type)
            short colID = (short)(colIndex);

            if (table.IsDBNull(colID))
            {
                row[colIndex] = null;
                return true;
            }

            String colName = schema.GetColumnName(colID);
            ULDbType colType = schema.GetColumnULDbType(colID);

            switch (colType)
            {
                case ULDbType.Binary:
                    row[colIndex] = table.GetBytes(colID);
                    break;
                case ULDbType.Bit:
                    row[colIndex] = table.GetBoolean(colID);
                    break;
                case ULDbType.Char:
                    row[colIndex] = table.GetString(colID);
                    break;
                case ULDbType.Date:
                    row[colIndex] = table.GetDateTime(colID);
                    break;
                case ULDbType.Double:
                    row[colIndex] = table.GetDouble(colID);
                    break;
                case ULDbType.LongBinary:
                    row[colIndex] = table.GetBytes(colID);
                    break;
                case ULDbType.LongVarchar:
                    row[colIndex] = table.GetString(colID);
                    break;
                case ULDbType.Numeric:
                    row[colIndex] = table.GetString(colID);
                    break;
                case ULDbType.Real:
                    row[colIndex] = table.GetFloat(colID);
                    break;
                case ULDbType.BigInt:
                    row[colIndex] = table.GetInt64(colID);
                    break;
                case ULDbType.Integer:
                    row[colIndex] = table.GetInt32(colID);
                    break;
                case ULDbType.SmallInt:
                    row[colIndex] = table.GetInt16(colID);
                    break;
                case ULDbType.Time:
                    row[colIndex] = table.GetDateTime(colID);
                    break;
                case ULDbType.TimeStamp:
                    row[colIndex] = table.GetDateTime(colID);
                    break;
                case ULDbType.TinyInt:
                    row[colIndex] = table.GetBytes(colID);
                    break;
                case ULDbType.UnsignedBigInt:
                    row[colIndex] = table.GetUInt64(colID);
                    break;
                case ULDbType.UnsignedInt:
                    row[colIndex] = table.GetUInt32(colID);
                    break;
                case ULDbType.UnsignedSmallInt:
                    row[colIndex] = table.GetUInt16(colID);
                    break;
                case ULDbType.VarChar:
                    row[colIndex] = table.GetString(colID);
                    break;
                default:
                    return false;
            }

            return true;
        }
    }
}
